@@ -2,11 +2,11 @@ from pprint import pprint
 from sqlalchemy import BigInteger,\
                        Column
 
-from sqlalchemy_api_handler.bases.save import Save
-from sqlalchemy_api_handler.utils.human_ids import humanize
+from sqlalchemy_api_handler.bases.activator import Activator
+from sqlalchemy_api_handler.utils.humanize import humanize
 
 
-class ApiHandler(Save):
+class ApiHandler(Activator):
 
     id = Column(BigInteger,
                 primary_key=True,
